package com.cyl.manager.act.service;

import java.util.Arrays;
import java.util.List;
import java.time.LocalDateTime;
import java.util.Optional;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.cyl.manager.act.domain.entity.ActivityApplyInfo;
import com.cyl.manager.act.domain.query.ActivityApplyInfoQuery;
import com.cyl.manager.act.mapper.ActivityApplyInfoMapper;
import com.cyl.manager.act.mapper.ActivityInfoMapper;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Pageable;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

/**
 * 活动报名信息Service业务层处理
 *
 * @author zcc
 */
@Service
public class ActivityApplyInfoService {
    @Autowired
    private ActivityApplyInfoMapper activityApplyInfoMapper;

    @Autowired
    private ActivityInfoMapper activityInfoMapper;

    /**
     * 查询活动报名信息
     *
     * @param id 活动报名信息主键
     * @return 活动报名信息
     */
    public ActivityApplyInfo selectById(Long id) {
        return activityApplyInfoMapper.selectById(id);
    }

    /**
     * 查询活动报名信息列表
     *
     * @param query 查询条件
     * @param page  分页条件
     * @return 活动报名信息
     */
    public List<ActivityApplyInfo> selectList(ActivityApplyInfoQuery query, Pageable page) {
        if (page != null) {
            PageHelper.startPage(page.getPageNumber() + 1, page.getPageSize());
        }
        QueryWrapper<ActivityApplyInfo> qw = new QueryWrapper<>();
        qw.eq("del_flag", "0");
        String cancelUserName = query.getCancelUserName();
        if (StringUtils.isNotEmpty(cancelUserName)) {
            qw.like("cancel_user_name", cancelUserName);
        }
        if (null != query.getUserId()) {
            qw.eq("user_id", query.getUserId());
        }
        String activityTitle = query.getActivityTitle();
        if (StringUtils.isNotEmpty(activityTitle)) {
            qw.like("activity_title", activityTitle);
        }
        String status = query.getStatus();
        if (!StringUtils.isEmpty(status)) {
            qw.eq("status", status);
        }
        List<ActivityApplyInfo> activityApplyInfos = activityApplyInfoMapper.selectList(qw);
        if (CollectionUtils.isNotEmpty(activityApplyInfos)) {
            activityApplyInfos.forEach(activityApplyInfo -> {
                Optional.ofNullable(activityInfoMapper.selectById(activityApplyInfo.getActivityId()))
                        .ifPresent(activityInfo -> {
                            activityApplyInfo.setActivityTitle(activityInfo.getActivityTitle());
                            activityApplyInfo.setActivityDate(activityInfo.getActivityDate());
                            activityApplyInfo.setActivityAddress(activityInfo.getActivityAddress());
                            activityApplyInfo.setApplyStartTime(activityInfo.getApplyStartTime());
                            activityApplyInfo.setApplyEndTime(activityInfo.getApplyEndTime());
                        });
            });
        }
        return activityApplyInfos;
    }

    /**
     * 新增活动报名信息
     *
     * @param activityApplyInfo 活动报名信息
     * @return 结果
     */
    public int insert(ActivityApplyInfo activityApplyInfo) {
        activityApplyInfo.setDelFlag("0");
        activityApplyInfo.setCreateTime(LocalDateTime.now());
        return activityApplyInfoMapper.insert(activityApplyInfo);
    }

    /**
     * 修改活动报名信息
     *
     * @param activityApplyInfo 活动报名信息
     * @return 结果
     */
    public int update(ActivityApplyInfo activityApplyInfo) {
        return activityApplyInfoMapper.updateById(activityApplyInfo);
    }

    /**
     * 批量删除活动报名信息
     *
     * @param ids 需要删除的活动报名信息主键
     * @return 结果
     */
    public int deleteByIds(Long[] ids) {
        return activityApplyInfoMapper.updateDelFlagByIds(ids);
    }

    /**
     * 删除活动报名信息信息
     *
     * @param id 活动报名信息主键
     * @return 结果
     */
    public int deleteById(Long id) {
        Long[] ids = {id};
        return activityApplyInfoMapper.updateDelFlagByIds(ids);
    }
}
